@@ -24,6 +24,7 @@
 import gettext
 import optparse
 import re
+import shutil
 import sys
 import textwrap
 
@@ -39,7 +40,7 @@ SUPPRESS_HELP = optparse.SUPPRESS_HELP
 
 diskcheck_all = SCons.Node.FS.diskcheck_types()
 
-experimental_features = {'warp_speed', 'transporter', 'ninja'}
+experimental_features = {'warp_speed', 'transporter', 'ninja', 'legacy_sched'}
 
 
 def diskcheck_convert(value):
@@ -53,7 +54,10 @@ def diskcheck_convert(value):
         if v == 'all':
             result = diskcheck_all
         elif v == 'none':
-            result = []
+            # Don't use an empty list here as that fails the normal check
+            # to see if an optparse parser of if parser.argname:
+            # Changed to ['none'] as diskcheck expects a list value
+            result = ['none']
         elif v in diskcheck_all:
             result.append(v)
         else:
@@ -64,7 +68,7 @@ def diskcheck_convert(value):
 class SConsValues(optparse.Values):
     """
     Holder class for uniform access to SCons options, regardless
-    of whether or not they can be set on the command line or in the
+    of whether they can be set on the command line or in the
     SConscript files (using the SetOption() function).
 
     A SCons option value can originate three different ways:
@@ -94,7 +98,7 @@ class SConsValues(optparse.Values):
     in the set_option() method.
     """
 
-    def __init__(self, defaults):
+    def __init__(self, defaults) -> None:
         self.__defaults__ = defaults
         self.__SConscript_settings__ = {}
 
@@ -146,11 +150,12 @@ class SConsValues(optparse.Values):
         'warn',
 
         # TODO: Remove these once we update the AddOption() API to allow setting
-        #       added flag as setable.
-        # Requested setable flag in : https://github.com/SCons/scons/issues/3983
+        #       added flag as settable.
+        # Requested settable flag in : https://github.com/SCons/scons/issues/3983
         # From experimental ninja
         'disable_execute_ninja',
-        'disable_ninja'
+        'disable_ninja',
+        'skip_ninja_regen'
     ]
 
     def set_option(self, name, value):
@@ -239,8 +244,7 @@ class SConsOption(optparse.Option):
         if value is not None:
             if self.nargs in (1, '?'):
                 return self.check_value(opt, value)
-            else:
-                return tuple([self.check_value(opt, v) for v in value])
+            return tuple([self.check_value(opt, v) for v in value])
 
     def process(self, opt, value, values, parser):
 
@@ -267,8 +271,7 @@ class SConsOption(optparse.Option):
 
 
 class SConsOptionGroup(optparse.OptionGroup):
-    """
-    A subclass for SCons-specific option groups.
+    """A subclass for SCons-specific option groups.
 
     The only difference between this and the base class is that we print
     the group's help text flush left, underneath their own title but
@@ -276,35 +279,59 @@ class SConsOptionGroup(optparse.OptionGroup):
     """
 
     def format_help(self, formatter):
-        """
-        Format an option group's help text, outdenting the title so it's
-        flush with the "SCons Options" title we print at the top.
+        """ Format an option group's help text.
+
+        The title is dedented so it's flush with the "SCons Options"
+        title we print at the top.
         """
         formatter.dedent()
         result = formatter.format_heading(self.title)
         formatter.indent()
-        result = result + optparse.OptionContainer.format_help(self, formatter)
+        # bypass OptionGroup format_help and call up to its parent
+        result += optparse.OptionContainer.format_help(self, formatter)
         return result
 
 
+class SConsBadOptionError(optparse.BadOptionError):
+    """Exception used to indicate that invalid command line options were specified
+
+    :ivar str opt_str: The offending option specified on command line which is not recognized
+    :ivar OptionParser parser: The active argument parser
+
+    """
+
+    def __init__(self, opt_str, parser=None) -> None:
+        self.opt_str = opt_str
+        self.parser = parser
+
+    def __str__(self) -> str:
+        return _("no such option: %s") % self.opt_str
+
+
 class SConsOptionParser(optparse.OptionParser):
     preserve_unknown_options = False
+    raise_exception_on_error = False
 
     def error(self, msg):
-        # overridden OptionValueError exception handler
-        self.print_usage(sys.stderr)
-        sys.stderr.write("SCons Error: %s\n" % msg)
-        sys.exit(2)
+        """
+        overridden OptionValueError exception handler
+        """
+        if self.raise_exception_on_error:
+            raise SConsBadOptionError(msg, self)
+        else:
+            self.print_usage(sys.stderr)
+            sys.stderr.write("SCons Error: %s\n" % msg)
+            sys.exit(2)
 
     def _process_long_opt(self, rargs, values):
-        """
-        SCons-specific processing of long options.
+        """ SCons-specific processing of long options.
 
         This is copied directly from the normal
-        optparse._process_long_opt() method, except that, if configured
+        ``optparse._process_long_opt()`` method, except that, if configured
         to do so, we catch the exception thrown when an unknown option
         is encountered and just stick it back on the "leftover" arguments
-        for later (re-)processing.
+        for later (re-)processing. This is because we may see the option
+        definition later, while processing SConscript files.
         """
         arg = rargs.pop(0)
 
@@ -369,7 +396,7 @@ class SConsOptionParser(optparse.OptionParser):
 
         option.process(opt, value, values, self)
 
-    def reparse_local_options(self):
+    def reparse_local_options(self) -> None:
         """ Re-parse the leftover command-line options.
 
         Parse options stored in `self.largs`, so that any value
@@ -433,10 +460,9 @@ class SConsOptionParser(optparse.OptionParser):
         self.largs = self.largs + largs_restore
 
     def add_local_option(self, *args, **kw):
-        """
-        Adds a local option to the parser.
+        """ Adds a local option to the parser.
 
-        This is initiated by an AddOption() call to add a user-defined
+        This is initiated by an :func:`AddOption` call to add a user-defined
         command-line option.  We add the option to a separate option
         group for the local options, creating the group if necessary.
         """
@@ -448,7 +474,6 @@ class SConsOptionParser(optparse.OptionParser):
             self.local_option_group = group
 
         result = group.add_option(*args, **kw)
-
         if result:
             # The option was added successfully.  We now have to add the
             # default value to our object that holds the default values
@@ -463,57 +488,105 @@ class SConsOptionParser(optparse.OptionParser):
 
         return result
 
+    def format_local_option_help(self, formatter=None, file=None):
+        """Return the help for the project-level ("local") options.
+
+        .. versionadded:: 4.6.0
+        """
+        if formatter is None:
+            formatter = self.formatter
+        try:
+            group = self.local_option_group
+        except AttributeError:
+            return ""
+
+        formatter.store_local_option_strings(self, group)
+        for opt in group.option_list:
+            strings = formatter.format_option_strings(opt)
+            formatter.option_strings[opt] = strings
+
+        # defeat our own cleverness, which starts out by dedenting
+        formatter.indent()
+        local_help = group.format_help(formatter)
+        formatter.dedent()
+        return local_help
+
+    def print_local_option_help(self, file=None):
+        """Print help for just project-defined options.
+
+        Writes to *file* (default stdout).
+
+        .. versionadded:: 4.6.0
+        """
+        if file is None:
+            file = sys.stdout
+        file.write(self.format_local_option_help())
+
 
 class SConsIndentedHelpFormatter(optparse.IndentedHelpFormatter):
-    def format_usage(self, usage):
+    def format_usage(self, usage) -> str:
+        """ Formats the usage message. """
         return "usage: %s\n" % usage
 
     def format_heading(self, heading):
-        """
-        This translates any heading of "options" or "Options" into
-        "SCons Options."  Unfortunately, we have to do this here,
-        because those titles are hard-coded in the optparse calls.
+        """ Translates heading to "SCons Options"
+
+        Heading of "Options" changed to "SCons Options."
+        Unfortunately, we have to do this here, because those titles
+        are hard-coded in the optparse calls.
         """
         if heading == 'Options':
             heading = "SCons Options"
-        return optparse.IndentedHelpFormatter.format_heading(self, heading)
+        return super().format_heading(heading)
 
     def format_option(self, option):
-        """
-        A copy of the normal optparse.IndentedHelpFormatter.format_option()
+        """ Customized option formatter.
+
+        A copy of the normal ``optparse.IndentedHelpFormatter.format_option()``
         method.  This has been snarfed so we can modify text wrapping to
-        out liking:
+        our liking:
 
-        --  add our own regular expression that doesn't break on hyphens
-            (so things like --no-print-directory don't get broken);
+        * add our own regular expression that doesn't break on hyphens
+          (so things like ``--no-print-directory`` don't get broken).
+        * wrap the list of options themselves when it's too long
+          (the ``wrapper.fill(opts)`` call below).
+        * set the :attr:`subsequent_indent` when wrapping the :attr:`help_text`.
 
-        --  wrap the list of options themselves when it's too long
-            (the wrapper.fill(opts) call below);
+        The help for each option consists of two parts:
 
-        --  set the subsequent_indent when wrapping the help_text.
+        * the opt strings and metavars e.g. ("-x", or
+          "-fFILENAME, --file=FILENAME")
+        * the user-supplied help string e.g.
+          ("turn on expert mode", "read data from FILENAME")
+
+        If possible, we write both of these on the same line::
+
+          -x      turn on expert mode
+
+        But if the opt string list is too long, we put the help
+        string on a second line, indented to the same column it would
+        start in if it fit on the first line::
+
+          -fFILENAME, --file=FILENAME
+                  read data from FILENAME
         """
-        # The help for each option consists of two parts:
-        #   * the opt strings and metavars
-        #     eg. ("-x", or "-fFILENAME, --file=FILENAME")
-        #   * the user-supplied help string
-        #     eg. ("turn on expert mode", "read data from FILENAME")
-        #
-        # If possible, we write both of these on the same line:
-        #   -x      turn on expert mode
-        #
-        # But if the opt string list is too long, we put the help
-        # string on a second line, indented to the same column it would
-        # start in if it fit on the first line.
-        #   -fFILENAME, --file=FILENAME
-        #           read data from FILENAME
         result = []
-
         opts = self.option_strings[option]
         opt_width = self.help_position - self.current_indent - 2
-        if len(opts) > opt_width:
-            wrapper = textwrap.TextWrapper(width=self.width,
-                                           initial_indent='  ',
-                                           subsequent_indent='  ')
+        # SCons: pre-compute if we could combine opts and text on one line,
+        # even if opts spills over opt_width. Saves some lines.
+        # Note: check is currently disabled and this removed from docstring:
+        # * if it would all fit on one line even if opts are long, don't break.
+        combine_anyway = False
+        if option.help:
+            help_text = self.expand_default(option)
+            # if len(opts) > opt_width and len(opts) + len(help_text) + 2 <= self.width:
+            #     combine_anyway = True
+        if len(opts) > opt_width and not combine_anyway:
+            # SCons: wrap options if needed
+            wrapper = textwrap.TextWrapper(
+                width=self.width, initial_indent='  ', subsequent_indent='  '
+            )
             wrapper.wordsep_re = no_hyphen_re
             opts = wrapper.fill(opts) + '\n'
             indent_first = self.help_position
@@ -522,12 +595,12 @@ class SConsIndentedHelpFormatter(optparse.IndentedHelpFormatter):
             indent_first = 0
         result.append(opts)
         if option.help:
-
-            help_text = self.expand_default(option)
-
-            # SCons:  indent every line of the help text but the first.
-            wrapper = textwrap.TextWrapper(width=self.help_width,
-                                           subsequent_indent='  ')
+            # this is now done above in the pre-check.
+            # help_text = self.expand_default(option)
+            # SCons: indent every line of the help text but the first.
+            wrapper = textwrap.TextWrapper(
+                width=self.help_width, subsequent_indent='  '
+            )
             wrapper.wordsep_re = no_hyphen_re
             help_lines = wrapper.wrap(help_text)
             result.append("%*s%s\n" % (indent_first, "", help_lines[0]))
@@ -537,45 +610,60 @@ class SConsIndentedHelpFormatter(optparse.IndentedHelpFormatter):
             result.append("\n")
         return "".join(result)
 
+    def store_local_option_strings(self, parser, group):
+        """Local-only version of store_option_strings.
+
+        We need to replicate this so the formatter will be set up
+        properly if we didn't go through the "normal" store_option_strings
+
+        .. versionadded:: 4.6.0
+        """
+        self.indent()
+        max_len = 0
+        for opt in group.option_list:
+            strings = self.format_option_strings(opt)
+            self.option_strings[opt] = strings
+            max_len = max(max_len, len(strings) + self.current_indent)
+        self.dedent()
+        self.help_position = min(max_len + 2, self.max_help_position)
+        self.help_width = max(self.width - self.help_position, 11)
+
 
 def Parser(version):
+    """Returns a parser object initialized with the standard SCons options.
+
+    Add options in the order we want them to show up in the ``-H`` help
+    text, basically alphabetical.  Each ``op.add_option()`` call
+    should have a consistent format::
+
+      op.add_option("-L", "--long-option-name",
+                    nargs=1, type="string",
+                    dest="long_option_name", default='foo',
+                    action="callback", callback=opt_long_option,
+                    help="help text goes here",
+                    metavar="VAR")
+
+    Even though the :mod:`optparse` module constructs reasonable default
+    destination names from the long option names, we're going to be
+    explicit about each one for easier readability and so this code
+    will at least show up when grepping the source for option attribute
+    names, or otherwise browsing the source code.
     """
-    Returns an options parser object initialized with the standard
-    SCons options.
-    """
-
-    formatter = SConsIndentedHelpFormatter(max_help_position=30)
-
-    op = SConsOptionParser(option_class=SConsOption,
-                           add_help_option=False,
-                           formatter=formatter,
-                           usage="usage: scons [OPTION] [TARGET] ...",)
-
+    columns, lines = shutil.get_terminal_size()
+    formatter = SConsIndentedHelpFormatter(max_help_position=30, width=columns)
+    op = SConsOptionParser(
+        option_class=SConsOption,
+        add_help_option=False,
+        formatter=formatter,
+        usage="usage: scons [OPTIONS] [VARIABLES] [TARGETS]",
+    )
     op.preserve_unknown_options = True
     op.version = version
 
-    # Add the options to the parser we just created.
-    #
-    # These are in the order we want them to show up in the -H help
-    # text, basically alphabetical.  Each op.add_option() call below
-    # should have a consistent format:
-    #
-    #   op.add_option("-L", "--long-option-name",
-    #                 nargs=1, type="string",
-    #                 dest="long_option_name", default='foo',
-    #                 action="callback", callback=opt_long_option,
-    #                 help="help text goes here",
-    #                 metavar="VAR")
-    #
-    # Even though the optparse module constructs reasonable default
-    # destination names from the long option names, we're going to be
-    # explicit about each one for easier readability and so this code
-    # will at least show up when grepping the source for option attribute
-    # names, or otherwise browsing the source code.
-
     # options ignored for compatibility
-    def opt_ignore(option, opt, value, parser):
+    def opt_ignore(option, opt, value, parser) -> None:
         sys.stderr.write("Warning:  ignoring %s option\n" % opt)
+
     op.add_option("-b", "-d", "-e", "-m", "-S", "-t", "-w",
                   "--environment-overrides",
                   "--no-keep-going",
@@ -584,46 +672,46 @@ def Parser(version):
                   "--stop",
                   "--touch",
                   action="callback", callback=opt_ignore,
-                  help="Ignored for compatibility.")
+                  help=SUPPRESS_HELP)
 
     op.add_option('-c', '--clean', '--remove',
                   dest="clean", default=False,
                   action="store_true",
-                  help="Remove specified targets and dependencies.")
+                  help="Remove specified targets and dependencies")
 
     op.add_option('-C', '--directory',
                   nargs=1, type="string",
                   dest="directory", default=[],
                   action="append",
-                  help="Change to DIR before doing anything.",
+                  help="Change to DIR before doing anything",
                   metavar="DIR")
 
     op.add_option('--cache-debug',
                   nargs=1,
                   dest="cache_debug", default=None,
                   action="store",
-                  help="Print CacheDir debug info to FILE.",
+                  help="Print CacheDir debug info to FILE",
                   metavar="FILE")
 
     op.add_option('--cache-disable', '--no-cache',
                   dest='cache_disable', default=False,
                   action="store_true",
-                  help="Do not retrieve built targets from CacheDir.")
+                  help="Do not retrieve built targets from CacheDir")
 
     op.add_option('--cache-force', '--cache-populate',
                   dest='cache_force', default=False,
                   action="store_true",
-                  help="Copy already-built targets into the CacheDir.")
+                  help="Copy already-built targets into the CacheDir")
 
     op.add_option('--cache-readonly',
                   dest='cache_readonly', default=False,
                   action="store_true",
-                  help="Do not update CacheDir with built targets.")
+                  help="Do not update CacheDir with built targets")
 
     op.add_option('--cache-show',
                   dest='cache_show', default=False,
                   action="store_true",
-                  help="Print build actions for files from CacheDir.")
+                  help="Print build actions for files from CacheDir")
 
     def opt_invalid(group, value, options):
         """report an invalid option from a group"""
@@ -637,7 +725,7 @@ def Parser(version):
 
     config_options = ["auto", "force", "cache"]
 
-    opt_config_help = "Controls Configure subsystem: %s." \
+    opt_config_help = "Controls Configure subsystem [%s]" \
                       % ", ".join(config_options)
 
     op.add_option('--config',
@@ -649,8 +737,8 @@ def Parser(version):
     op.add_option('-D',
                   dest="climb_up", default=None,
                   action="store_const", const=2,
-                  help="Search up directory tree for SConstruct,       "
-                       "build all Default() targets.")
+                  help="Search up directory tree for SConstruct, "
+                       "build all Default() targets")
 
     deprecated_debug_options = {}
 
@@ -664,7 +752,7 @@ def Parser(version):
     debug_options = ["count", "duplicate", "explain", "findlibs",
                      "includes", "memoizer", "memory", "objects",
                      "pdb", "prepare", "presub", "stacktrace",
-                     "time", "action-timestamps"]
+                     "time", "action-timestamps", "json", "sconscript"]
 
     def opt_debug(option, opt, value__, parser,
                   debug_options=debug_options,
@@ -690,7 +778,7 @@ def Parser(version):
                 raise OptionValueError(opt_invalid(
                     'debug', value, debug_options))
 
-    opt_debug_help = "Print various types of debugging information: %s." \
+    opt_debug_help = "Print various types of debugging information [%s]" \
                      % ", ".join(debug_options)
     op.add_option('--debug',
                   nargs=1, type="string",
@@ -710,7 +798,7 @@ def Parser(version):
                   nargs=1, type="string",
                   dest='diskcheck', default=None,
                   action="callback", callback=opt_diskcheck,
-                  help="Enable specific on-disk checks.",
+                  help="Enable specific on-disk checks",
                   metavar="TYPE")
 
     def opt_duplicate(option, opt, value, parser):
@@ -722,8 +810,8 @@ def Parser(version):
         # of SConscript files.
         SCons.Node.FS.set_duplicate(value)
 
-    opt_duplicate_help = "Set the preferred duplication methods. Must be one of " \
-                         + ", ".join(SCons.Node.FS.Valid_Duplicates)
+    opt_duplicate_help = "Set the preferred duplication methods [%s]" \
+                         % ", ".join(SCons.Node.FS.Valid_Duplicates)
 
     op.add_option('--duplicate',
                   nargs=1, type="string",
@@ -774,22 +862,22 @@ def Parser(version):
                   nargs=1, type="string",
                   dest="file", default=[],
                   action="append",
-                  help="Read FILE as the top-level SConstruct file.")
+                  help="Read FILE as the top-level SConstruct file")
 
     op.add_option('-h', '--help',
                   dest="help", default=False,
                   action="store_true",
-                  help="Print defined help message, or this one.")
+                  help="Print defined help message, or this one")
 
     op.add_option("-H", "--help-options",
                   action="help",
-                  help="Print this message and exit.")
+                  help="Print this message and exit")
 
-    def warn_md5_chunksize_deprecated(option, opt, value, parser):
+    def warn_md5_chunksize_deprecated(option, opt, value, parser) -> None:
         if opt == '--md5-chunksize':
-            SCons.Warnings.warn(SCons.Warnings.DeprecatedWarning,
-                                "Parameter %s is deprecated. Use "
-                                "--hash-chunksize instead." % opt)
+            SCons.Warnings.warn(SCons.Warnings.DeprecatedOptionsWarning,
+                                f"Option {opt} is deprecated. "
+                                "Use --hash-chunksize instead.")
 
         setattr(parser.values, option.dest, value)
 
@@ -797,25 +885,25 @@ def Parser(version):
                   nargs=1, type="int",
                   dest='md5_chunksize', default=SCons.Node.FS.File.hash_chunksize,
                   action="callback",
-                  help="Set chunk-size for hash signature computation to N kilobytes.",
+                  help="Set chunk-size for hash signature computation to N kilobytes",
                   callback=warn_md5_chunksize_deprecated,
                   metavar="N")
 
     op.add_option('--hash-format',
                   dest='hash_format',
                   action='store',
-                  help='Hash format (e.g. md5, sha1, or sha256).')
+                  help='Hash format [md5, sha1, sha256, etc].')
 
     op.add_option('-i', '--ignore-errors',
                   dest='ignore_errors', default=False,
                   action="store_true",
-                  help="Ignore errors from build actions.")
+                  help="Ignore errors from build actions")
 
     op.add_option('-I', '--include-dir',
                   nargs=1,
                   dest='include_dir', default=[],
                   action="append",
-                  help="Search DIR for imported Python modules.",
+                  help="Search DIR for imported Python modules",
                   metavar="DIR")
 
     op.add_option('--ignore-virtualenv',
@@ -828,100 +916,100 @@ def Parser(version):
                   action="store_true",
                   help="Cache implicit dependencies")
 
-    def opt_implicit_deps(option, opt, value, parser):
+    def opt_implicit_deps(option, opt, value, parser) -> None:
         setattr(parser.values, 'implicit_cache', True)
         setattr(parser.values, option.dest, True)
 
     op.add_option('--implicit-deps-changed',
                   dest="implicit_deps_changed", default=False,
                   action="callback", callback=opt_implicit_deps,
-                  help="Ignore cached implicit dependencies.")
+                  help="Ignore cached implicit dependencies")
 
     op.add_option('--implicit-deps-unchanged',
                   dest="implicit_deps_unchanged", default=False,
                   action="callback", callback=opt_implicit_deps,
-                  help="Ignore changes in implicit dependencies.")
+                  help="Ignore changes in implicit dependencies")
 
     op.add_option('--interact', '--interactive',
                   dest='interactive', default=False,
                   action="store_true",
-                  help="Run in interactive mode.")
+                  help="Run in interactive mode")
 
     op.add_option('-j', '--jobs',
                   nargs=1, type="int",
                   dest="num_jobs", default=1,
                   action="store",
-                  help="Allow N jobs at once.",
+                  help="Allow N jobs at once",
                   metavar="N")
 
     op.add_option('-k', '--keep-going',
                   dest='keep_going', default=False,
                   action="store_true",
-                  help="Keep going when a target can't be made.")
+                  help="Keep going when a target can't be made")
 
     op.add_option('--max-drift',
                   nargs=1, type="int",
                   dest='max_drift', default=SCons.Node.FS.default_max_drift,
                   action="store",
-                  help="Set maximum system clock drift to N seconds.",
+                  help="Set maximum system clock drift to N seconds",
                   metavar="N")
 
     op.add_option('-n', '--no-exec', '--just-print', '--dry-run', '--recon',
                   dest='no_exec', default=False,
                   action="store_true",
-                  help="Don't build; just print commands.")
+                  help="Don't build; just print commands")
 
     op.add_option('--no-site-dir',
                   dest='site_dir',
                   action="store_false",
-                  help="Don't search or use the usual site_scons dir.")
+                  help="Don't search or use the usual site_scons dir")
 
     op.add_option('--profile',
                   nargs=1,
                   dest="profile_file", default=None,
                   action="store",
-                  help="Profile SCons and put results in FILE.",
+                  help="Profile SCons and put results in FILE",
                   metavar="FILE")
 
     op.add_option('-q', '--question',
                   dest="question", default=False,
                   action="store_true",
-                  help="Don't build; exit status says if up to date.")
+                  help="Don't build; exit status says if up to date")
 
     op.add_option('-Q',
                   dest='no_progress', default=False,
                   action="store_true",
-                  help="Suppress \"Reading/Building\" progress messages.")
+                  help="Suppress \"Reading/Building\" progress messages")
 
     op.add_option('--random',
                   dest="random", default=False,
                   action="store_true",
-                  help="Build dependencies in random order.")
+                  help="Build dependencies in random order")
 
     op.add_option('-s', '--silent', '--quiet',
                   dest="silent", default=False,
                   action="store_true",
-                  help="Don't print commands.")
+                  help="Don't print commands")
 
     op.add_option('--site-dir',
                   nargs=1,
                   dest='site_dir', default=None,
                   action="store",
-                  help="Use DIR instead of the usual site_scons dir.",
+                  help="Use DIR instead of the usual site_scons dir",
                   metavar="DIR")
 
     op.add_option('--stack-size',
                   nargs=1, type="int",
                   dest='stack_size',
                   action="store",
-                  help="Set the stack size of the threads used to run jobs to N kilobytes.",
+                  help="Set the stack size of the threads used to run jobs to N kilobytes",
                   metavar="N")
 
     op.add_option('--taskmastertrace',
                   nargs=1,
                   dest="taskmastertrace_file", default=None,
                   action="store",
-                  help="Trace Node evaluation to FILE.",
+                  help="Trace Node evaluation to FILE",
                   metavar="FILE")
 
     tree_options = ["all", "derived", "prune", "status", "linedraw"]
@@ -943,7 +1031,7 @@ def Parser(version):
                 raise OptionValueError(opt_invalid('--tree', o, tree_options))
         parser.values.tree_printers.append(tp)
 
-    opt_tree_help = "Print a dependency tree in various formats: %s." \
+    opt_tree_help = "Print a dependency tree in various formats [%s]" \
                     % ", ".join(tree_options)
 
     op.add_option('--tree',
@@ -956,23 +1044,24 @@ def Parser(version):
     op.add_option('-u', '--up', '--search-up',
                   dest="climb_up", default=0,
                   action="store_const", const=1,
-                  help="Search up directory tree for SConstruct,       "
-                       "build targets at or below current directory.")
+                  help="Search up directory tree for SConstruct, "
+                       "build targets at or below current directory")
 
     op.add_option('-U',
                   dest="climb_up", default=0,
                   action="store_const", const=3,
-                  help="Search up directory tree for SConstruct,       "
-                       "build Default() targets from local SConscript.")
+                  help="Search up directory tree for SConstruct, "
+                       "build Default() targets from local SConscript")
 
-    def opt_version(option, opt, value, parser):
+    def opt_version(option, opt, value, parser) -> None:
         sys.stdout.write(parser.version + '\n')
         sys.exit(0)
+
     op.add_option("-v", "--version",
                   action="callback", callback=opt_version,
-                  help="Print the SCons version number and exit.")
+                  help="Print the SCons version number and exit")
 
-    def opt_warn(option, opt, value, parser, tree_options=tree_options):
+    def opt_warn(option, opt, value, parser, tree_options=tree_options) -> None:
         if SCons.Util.is_String(value):
             value = value.split(',')
         parser.values.warn.extend(value)
@@ -981,21 +1070,21 @@ def Parser(version):
                   nargs=1, type="string",
                   dest="warn", default=[],
                   action="callback", callback=opt_warn,
-                  help="Enable or disable warnings.",
+                  help="Enable or disable warnings",
                   metavar="WARNING-SPEC")
 
     op.add_option('-Y', '--repository', '--srcdir',
                   nargs=1,
                   dest="repository", default=[],
                   action="append",
-                  help="Search REPOSITORY for source and target files.")
+                  help="Search REPOSITORY for source and target files")
 
     # Options from Make and Cons classic that we do not yet support,
     # but which we may support someday and whose (potential) meanings
     # we don't want to change.  These all get a "the -X option is not
     # yet implemented" message and don't show up in the help output.
 
-    def opt_not_yet(option, opt, value, parser):
+    def opt_not_yet(option, opt, value, parser) -> None:
         msg = "Warning:  the %s option is not yet implemented\n" % opt
         sys.stderr.write(msg)
 
@@ -1005,62 +1094,62 @@ def Parser(version):
                   action="callback", callback=opt_not_yet,
                   # action="store",
                   # help="Don't start multiple jobs unless load is below "
-                  #      "LOAD-AVERAGE."
+                  #      "LOAD-AVERAGE"
                   help=SUPPRESS_HELP)
     op.add_option('--list-actions',
                   dest="list_actions",
                   action="callback", callback=opt_not_yet,
-                  # help="Don't build; list files and build actions."
+                  # help="Don't build; list files and build actions"
                   help=SUPPRESS_HELP)
     op.add_option('--list-derived',
                   dest="list_derived",
                   action="callback", callback=opt_not_yet,
-                  # help="Don't build; list files that would be built."
+                  # help="Don't build; list files that would be built"
                   help=SUPPRESS_HELP)
     op.add_option('--list-where',
                   dest="list_where",
                   action="callback", callback=opt_not_yet,
-                  # help="Don't build; list files and where defined."
+                  # help="Don't build; list files and where defined"
                   help=SUPPRESS_HELP)
     op.add_option('-o', '--old-file', '--assume-old',
                   nargs=1, type="string",
                   dest="old_file", default=[],
                   action="callback", callback=opt_not_yet,
                   # action="append",
-                  # help = "Consider FILE to be old; don't rebuild it."
+                  # help = "Consider FILE to be old; don't rebuild it"
                   help=SUPPRESS_HELP)
     op.add_option('--override',
                   nargs=1, type="string",
                   action="callback", callback=opt_not_yet,
                   dest="override",
-                  # help="Override variables as specified in FILE."
+                  # help="Override variables as specified in FILE"
                   help=SUPPRESS_HELP)
     op.add_option('-p',
                   action="callback", callback=opt_not_yet,
                   dest="p",
-                  # help="Print internal environments/objects."
+                  # help="Print internal environments/objects"
                   help=SUPPRESS_HELP)
     op.add_option('-r', '-R', '--no-builtin-rules', '--no-builtin-variables',
                   action="callback", callback=opt_not_yet,
                   dest="no_builtin_rules",
-                  # help="Clear default environments and variables."
+                  # help="Clear default environments and variables"
                   help=SUPPRESS_HELP)
     op.add_option('--write-filenames',
                   nargs=1, type="string",
                   dest="write_filenames",
                   action="callback", callback=opt_not_yet,
-                  # help="Write all filenames examined into FILE."
+                  # help="Write all filenames examined into FILE"
                   help=SUPPRESS_HELP)
     op.add_option('-W', '--new-file', '--assume-new', '--what-if',
                   nargs=1, type="string",
                   dest="new_file",
                   action="callback", callback=opt_not_yet,
-                  # help="Consider FILE to be changed."
+                  # help="Consider FILE to be changed"
                   help=SUPPRESS_HELP)
     op.add_option('--warn-undefined-variables',
                   dest="warn_undefined_variables",
                   action="callback", callback=opt_not_yet,
-                  # help="Warn when an undefined variable is referenced."
+                  # help="Warn when an undefined variable is referenced"
                   help=SUPPRESS_HELP)
     return op
 
